package info.kofler.recycler2

import android.content.Context
import android.graphics.Color
import android.util.Log
import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import info.kofler.recycler2.databinding.CountryitemBinding
import java.util.*

// countryitem.xml -> CountryitemBinding

class CountryVH(binding: CountryitemBinding) : RecyclerView.ViewHolder(binding.root) {
    val txtCountry: TextView    = binding.txtCountry
    val txtCapital: TextView    = binding.txtCapital
    val txtArea: TextView       = binding.txtArea
    val txtPopulation: TextView = binding.txtPopulation
    val imgFlag: ImageView      = binding.imgFlag
}

class CountryAdapter(private val countries: List<Country>,
                     private val context: Context)
    : RecyclerView.Adapter<CountryVH>()
{

    override fun getItemCount(): Int {
        return countries.size
    }

    override fun onCreateViewHolder(parent: ViewGroup,
                                    viewType: Int): CountryVH
    {
        val binding = CountryitemBinding.inflate(
            LayoutInflater.from(parent.context), parent, false)
        return CountryVH(binding)
    }

    override fun onBindViewHolder(holder: CountryVH,
                                  pos: Int)
    {
        holder.txtCountry.text = countries[pos].name
        holder.txtCapital.text = "(${countries[pos].capital})"
        holder.txtArea.text =
            "%,.0f km²".format(countries[pos].area)
        holder.txtPopulation.text =
            "%,d EW".format(countries[pos].population)
        if (countries[pos].isSelected)
            holder.itemView.setBackgroundColor(Color.LTGRAY)
        else
            holder.itemView.setBackgroundColor(Color.WHITE)

        // Bitmap der Flagge
        val rscname = context.packageName + ":drawable/" +
                countries[pos].name
                    .lowercase(Locale.GERMAN)
                    .replace("ü", "u")
                    .replace("-", "_")
        val id = context.resources.getIdentifier(rscname, null, null)
        holder.imgFlag.setImageResource(id)

        // Reaktion auf Auswahl des Listeneintrags
        holder.itemView.setOnClickListener {
            Log.i("xxx", "Listeneintrag $pos wurde ausgewählt.")
            countries[pos].isSelected = !countries[pos].isSelected
            this.notifyDataSetChanged()
        }
    }


}